const passport = require('../passeport-config');
const utils = require('../utils/writer.js');
const userService = require('../service/UserService');

module.exports = {
    // Route to initiate Google OAuth2 authentication
    googleAuth: (req, res, next) => {
        passport.authenticate('google', {
            scope: ['openid', 'profile', 'email'],
        })(req, res, next);
    },

    // Callback route for Google OAuth2 authentication
    googleAuthCallback: (req, res, next) => {
        passport.authenticate('google', (err, user, info) => {
            if (err) {
                return utils.writeJson(res, { error: err.message }, 500);
            }
            if (!user) {
                return utils.writeJson(res, { error: 'Authentication failed' }, 401);
            }
            userService.loginUser(req, res, next);
            return utils.writeJson(res, { message: 'Authentication succeeded' }, 200);
        })(req, res, next);
    },

    // Middleware to check if the user is authenticated
    isAuthenticated: (req, res, next) => {
        if (req.isAuthenticated()) {
            return next();
        }
        return utils.writeJson(res, { error: 'Authentication required' }, 401);
    },
};
