'use strict';

const passport = require('../passeport-config');
const User = require('../models/User');

passport.use(User.createStrategy());

/**
 * Create user
 * This can only be done by the logged in user.
 *
 * body User Created user object (optional)
 * returns User
 **/
exports.createUser = async function(username, password, isAgent) {
  const existingUser = await User.findOne({ username });

  if (existingUser) {
    throw new Error('This user already exists.');
  }

  await User.register(new User ({ username : username, isAgent : isAgent}), password);
};

exports.loginUser = function (req, res, next) {
  passport.authenticate('local', function (err, user, info) {
    if (err) {
      return next(err);
    }
    if (!user) {
      return res.status(401).json({ message: 'Authentication failed' });
    }

    req.logIn(user, function (err) {
      if (err) {
        return next(err);
      }
      return res.status(200).json({ message: 'Login successful', user });
    });
  })(req, res, next);
};

/**
 * Logs user into the system
 *
 * username String The user name for login (optional)
 * password String The password for login in clear text (optional)
 * returns String
 **/
exports.isAuthenticated = function (req, res, next) {
  if (req.isAuthenticated()) {
    return next();
  }
  res.status(401).json({ message: 'Authentification requise' });
}

